enum NodePublicationBatch {
Full {
nodes: Vec<Node>,
},
Incremental {
nodes: Vec<Node>,
absent_paths: Vec<String>,
expected_nodes: Vec<Node>,
},
}Expand description
Node mutations owned by one full or incremental publication.
Variants
Implementations
Sourceimpl NodePublicationBatch
impl NodePublicationBatch
Sourcefn expected_nodes(&self) -> &[Node]
fn expected_nodes(&self) -> &[Node]
Return the complete source state that must still exist before publication.