pub(crate) enum SettingsCapabilityState {
Ready,
Empty,
Unavailable,
}Expand description
Readiness of one settings capability.
Variants
Ready
The capability has usable persisted state.
Empty
The capability is implemented but the selected index has no rows yet.
The capability is not available in the current runtime/index combination.