enum SymbolProjectionChange {
Parsed(SymbolParseSuccess),
Clear {
path: String,
language: Option<String>,
},
}Expand description
One closed symbol projection mutation.
Variants
Parsed(SymbolParseSuccess)
Persist one successfully parsed graph and its derived metadata.
Clear
Clear stale symbol output for a skipped source file.