fn apply_symbol_build_stage(
store: &mut AtlasStore,
staged: &SymbolBuildStage,
control: &IndexWorkControl,
) -> Result<(), CliError>Expand description
Apply prepared symbol mutations inside the parent publication transaction.
fn apply_symbol_build_stage(
store: &mut AtlasStore,
staged: &SymbolBuildStage,
control: &IndexWorkControl,
) -> Result<(), CliError>Apply prepared symbol mutations inside the parent publication transaction.