fn complete_index_publication(
publication: IndexPublicationGuard<'_>,
control: &IndexWorkControl,
) -> Result<(), CliError>Expand description
Commit only after the shared work boundary still permits publication.
fn complete_index_publication(
publication: IndexPublicationGuard<'_>,
control: &IndexWorkControl,
) -> Result<(), CliError>Commit only after the shared work boundary still permits publication.