fn empty_index_refresh_report(
text_options: TextIndexOptions,
) -> IndexRefreshReportExpand description
Build the stable report for a verified watcher no-op.
fn empty_index_refresh_report(
text_options: TextIndexOptions,
) -> IndexRefreshReportBuild the stable report for a verified watcher no-op.