fn health_next_start_index(page: &HealthFindingsPage) -> Option<usize>Expand description
Return the next start index for a bounded health page.
fn health_next_start_index(page: &HealthFindingsPage) -> Option<usize>Return the next start index for a bounded health page.