pub(crate) fn index_work_control(
options: &SymbolBuildOptions,
) -> IndexWorkControlExpand description
Create one indexing boundary with the caller timeout capped by the safe default.
pub(crate) fn index_work_control(
options: &SymbolBuildOptions,
) -> IndexWorkControlCreate one indexing boundary with the caller timeout capped by the safe default.