pub(crate) fn indexed_project_root(
store: &AtlasStore,
) -> Result<PathBuf, CliError>Expand description
Load the project root recorded by the latest scan.
pub(crate) fn indexed_project_root(
store: &AtlasStore,
) -> Result<PathBuf, CliError>Load the project root recorded by the latest scan.