fn open_atlas_store_for_project_with_location_validator<F>(
path: &Path,
root: &Path,
validate_location: F,
) -> Result<AtlasStore, CliError>Expand description
Validate storage before creating the database parent and opening the store.
fn open_atlas_store_for_project_with_location_validator<F>(
path: &Path,
root: &Path,
validate_location: F,
) -> Result<AtlasStore, CliError>Validate storage before creating the database parent and opening the store.