pub(crate) fn primary_symbol_kinds(graph: &SymbolGraph) -> StringExpand description
Return a compact phrase describing the most important symbol kinds.
pub(crate) fn primary_symbol_kinds(graph: &SymbolGraph) -> StringReturn a compact phrase describing the most important symbol kinds.