pub(crate) fn primary_symbol_names(
graph: &SymbolGraph,
limit: usize,
) -> Vec<String>Expand description
Return stable names for the most important declaration symbols.
pub(crate) fn primary_symbol_names(
graph: &SymbolGraph,
limit: usize,
) -> Vec<String>Return stable names for the most important declaration symbols.