fn publication_contract_matches(
store: &AtlasStore,
plan: &ScanRuntimePlan,
) -> Result<bool, CliError>Expand description
Return whether symbol reuse and incremental publication share the current derivation contract.
fn publication_contract_matches(
store: &AtlasStore,
plan: &ScanRuntimePlan,
) -> Result<bool, CliError>Return whether symbol reuse and incremental publication share the current derivation contract.