fn purpose_queue_curation_scope(query: &HealthQuery) -> &'static strExpand description
Return the truthful curation tier selected by explicit queue scope flags.
fn purpose_queue_curation_scope(query: &HealthQuery) -> &'static strReturn the truthful curation tier selected by explicit queue scope flags.