fn purpose_queue_folder_scope(query: &HealthQuery) -> &'static strExpand description
Return the folder inclusion scope for purpose curation metadata.
fn purpose_queue_folder_scope(query: &HealthQuery) -> &'static strReturn the folder inclusion scope for purpose curation metadata.