fn settings_publication_matches(
diagnostic: Option<&DatabasePublicationReport>,
snapshot: Option<&IndexPublication>,
) -> boolExpand description
Reject mixed settings projections when publication changed between read snapshots.
fn settings_publication_matches(
diagnostic: Option<&DatabasePublicationReport>,
snapshot: Option<&IndexPublication>,
) -> boolReject mixed settings projections when publication changed between read snapshots.