fn staged_full_refresh_is_unchanged(
store: &AtlasStore,
batch: &IndexPublicationBatch,
) -> Result<bool, CliError>Expand description
Return whether one fully staged watcher refresh matches complete durable state.
fn staged_full_refresh_is_unchanged(
store: &AtlasStore,
batch: &IndexPublicationBatch,
) -> Result<bool, CliError>Return whether one fully staged watcher refresh matches complete durable state.