pub(crate) fn standalone_index_work_control() -> IndexWorkControlExpand description
Create a bounded work boundary for runtime paths without symbol options.
pub(crate) fn standalone_index_work_control() -> IndexWorkControlCreate a bounded work boundary for runtime paths without symbol options.