pub(crate) struct StructuralSummaryReport {
pub(crate) candidates: usize,
pub(crate) summarized: usize,
pub(crate) cleared: usize,
pub(crate) too_large: usize,
pub(crate) binary_or_non_utf8: usize,
pub(crate) purpose_suggestions: usize,
}Expand description
Deterministic structural-summary refresh report.
Fields
candidates: usizeIndexed files considered for structural summaries.
summarized: usizeFiles whose observed summaries were refreshed.
cleared: usizeExisting observed summaries cleared because current content was not summarizable.
too_large: usizeFiles skipped because they exceeded the parser size limit.
binary_or_non_utf8: usizeFiles skipped because content was not valid UTF-8.
purpose_suggestions: usizeGenerated purpose suggestions that still need agent review.