UsageRuntimeInstance

Struct UsageRuntimeInstance 

pub(crate) struct UsageRuntimeInstance {
    id: UsageInstanceId,
    owner: UsageInstanceOwner,
}
One optional telemetry identity owned by a CLI invocation or MCP process.

Fields

id: UsageInstanceId

Opaque runtime-owned identity persisted with usage events.

owner: UsageInstanceOwner

Adapter lifecycle that owns sealing this identity.

Implementations

Source

impl UsageRuntimeInstance

pub(crate) fn new(owner: UsageInstanceOwner) -> Option<Self>

Create an opaque runtime identity when operating-system entropy is available.

fn record(self, store: &AtlasStore, event: &UsageEvent) -> Result<(), CliError>

Record one event using the lifecycle implied by this runtime owner.

pub(crate) fn seal(self, store: &AtlasStore) -> Result<(), CliError>

Seal this runtime instance in one selected project database.