pub(crate) struct SettingsReport {Show 26 fields
pub(crate) cache_dir: PathStatus,
pub(crate) db: PathStatus,
pub(crate) db_wal: PathStatus,
pub(crate) db_shm: PathStatus,
pub(crate) db_journal: PathStatus,
pub(crate) mcp_config: PathStatus,
pub(crate) config_path: Option<String>,
pub(crate) repo_root: String,
pub(crate) root_detection_source: String,
pub(crate) root_verified: bool,
pub(crate) root_mismatches: Vec<String>,
pub(crate) map_path: String,
pub(crate) nonsource_files_path: String,
pub(crate) default_format: String,
pub(crate) default_search_case_sensitive: bool,
pub(crate) search_source: String,
pub(crate) text_index_max_bytes: u64,
pub(crate) watcher: WatchStatusReport,
pub(crate) index: Option<SettingsIndexStats>,
pub(crate) telemetry: Option<TelemetryRetentionState>,
pub(crate) database: DatabaseSettingsReport,
pub(crate) language_registry: LanguageRegistryReport,
pub(crate) semantic_relation_contract_digest: String,
pub(crate) relation_family_inventory: RelationFamilyInventoryReport,
pub(crate) search: SettingsSearchReport,
pub(crate) optional_parser_pack: OptionalParserSettingsReport,
}Expand description
Local settings report.
Fields
cache_dir: PathStatusRuntime cache directory that owns local ProjectAtlas state.
db: PathStatusSQLite database file status.
db_wal: PathStatusSQLite write-ahead log file status.
db_shm: PathStatusSQLite shared-memory sidecar file status.
db_journal: PathStatusSQLite rollback journal sidecar file status.
mcp_config: PathStatusProject-local MCP configuration file status.
config_path: Option<String>Config file used for map/lint/scan imports, when discovered.
repo_root: StringRepository root used by map/lint config.
root_detection_source: StringSource that selected the repository root.
root_verified: boolWhether config and DB root metadata agree.
root_mismatches: Vec<String>Root mismatches that should be fixed before trusting the binding.
map_path: StringGenerated map path.
nonsource_files_path: StringNon-source summary path.
default_format: StringDefault output format.
default_search_case_sensitive: boolDefault search case sensitivity.
search_source: StringSource used by search commands.
text_index_max_bytes: u64Maximum UTF-8 file size persisted into SQLite text search.
watcher: WatchStatusReportWatcher runtime status.
index: Option<SettingsIndexStats>Current index statistics, if the index exists.
telemetry: Option<TelemetryRetentionState>Content-free telemetry retention and maintenance state, when the index exists.
database: DatabaseSettingsReportRead-only schema, publication, coverage, and SQLite operating diagnostics.
language_registry: LanguageRegistryReportContent-free language capability registry identity and derived counts.
semantic_relation_contract_digest: StringDigest of the currently implemented provider-backed relation contract.
relation_family_inventory: RelationFamilyInventoryReportVersioned accepted relation-family inventory and lifecycle state.
search: SettingsSearchReportTyped search-mode readiness without an implicit index build.
optional_parser_pack: OptionalParserSettingsReportContent-free optional parser-pack lifecycle state.